@@ -4,9 +4,10 @@
 
 from labstep.entities.jupyterNotebook.model import JupyterNotebook
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
-def newJupyterNotebook(user, name=None, data=None):
+def newJupyterNotebook(user, name=UNSPECIFIED, data=UNSPECIFIED):
     return entityRepository.newEntity(user, JupyterNotebook, {"name": name, "data": data})
 
 
@@ -16,9 +17,9 @@ def getJupyterNotebook(user, guid):
 
 def editJupyterNotebook(
     jupyterNotebook,
-    name=None,
-    status=None,
-    data=None,
+    name=UNSPECIFIED,
+    status=UNSPECIFIED,
+    data=UNSPECIFIED,
     extraParams={},
 ):
     params = {
