@@ -7,9 +7,10 @@ import labstep.generic.entity.repository as entityRepository
 from labstep.service.helpers import url_join, getHeaders
 from labstep.service.config import configService
 from labstep.service.request import requestService
+from labstep.constants import UNSPECIFIED
 
 
-def getMembers(user, workspace_id, count=100, search_query=None, extraParams={}):
+def getMembers(user, workspace_id, count=100, search_query=UNSPECIFIED, extraParams={}):
 
     params = {"group_id": workspace_id,
               "search_query_user": search_query, **extraParams}
